# cxpandascsvloader
A simple example package for loading and processing CSV data into Pandas DataFrames.

## Installation
You can install the `cxpandascsvloader` package using pip:

```sh
pip install cxcsvtopandas
```

## Usage
```sh
% python                        
Python 3.9.20 (main, Oct 19 2024, 17:36:14) 
[Clang 15.0.0 (clang-1500.3.9.4)] on darwin
Type "help", "copyright", "credits" or "license" for more information.
>>> import cxcsvtopandas.dataframeloader as dfl
>>> dfl.printinfo()
dataframeloader module loaded.
```

